@@ -153,12 +153,14 @@ class set:
                 try:
                     camera = PiCamera()
                     camera.capture('/home/pi/image.jpg')
-                    sleep(5)
+                    time.sleep(5)
+                    print("Fotoğraf çekildi")
                 except Exception as identifier:
                     print("Fotoğraf çekilemedi")
                 try:
                     update.message.reply_photo(photo=open('/home/pi/image.jpg','photo'))                
                     update.message.reply_text("Bütün Kullanıcılar Silindi")
+                    print("Fotoğraf gönderildi")
                 except Exception as identifier:
                     print("Fotograf gönderilemedi")
                 
